@@ -2,7 +2,7 @@
 # http://opensource.org/licenses/mit-license.php or see LICENSE file.
 # Copyright 2007-2008 Brisa Team <brisa-develop@garage.maemo.org>
 
-from brisa import config
+from brisa.core import config
 
 
 def check_config():
