@@ -4,7 +4,7 @@
 
 import os
 
-from brisa import config
+from brisa.core import config
 
 
 plugin = 'media_server_plugin-shoutcast'
